# Social Media Opener 
A Python Package to open the social media whose links are of the pattern https://<social-media-name>.com from your Command line Interface.

# Usage
Following query will open the browser with the social-media you have written.

'''
open-this <space> <social-media-name>
'''
